@@ -6,7 +6,6 @@
 #include <memory>
 
 #include <botan/botan.h>
-#include <botan/libstate.h>
 #include <botan/rsa.h>
 #include <botan/dsa.h>
 #include <botan/dh.h>
@@ -19,12 +18,10 @@
 #include <botan/filters.h>
 #include <botan/look_pk.h>
 #include <botan/numthry.h>
-
-#include <botan/x931_rng.h>
-#include <botan/libstate.h>
 using namespace Botan;
 
 #include "common.h"
+#include "validate.h"
 
 static BigInt to_bigint(const std::string& h)
    {
@@ -34,175 +31,7 @@ static BigInt to_bigint(const std::string& h)
 
 #define DEBUG 0
 
-class Fixed_Output_RNG : public RandomNumberGenerator
-   {
-   public:
-      bool is_seeded() const { return true; }
-
-      byte random()
-         {
-         if(position < output.size())
-            return output[position++];
-
-         throw Botan::Invalid_State("Fixed_Output_RNG: out of bits");
-         }
-      void randomize(byte out[], u32bit len) throw()
-         {
-         for(u32bit j = 0; j != len; j++)
-            out[j] = random();
-         }
-      std::string name() const { return "Fixed_Output_RNG"; }
-      void clear() throw() {}
-      void add_randomness(const byte[], u32bit) throw() {}
-      Fixed_Output_RNG(const SecureVector<byte>& x)
-         {
-         output = x;
-         position = 0;
-         }
-   private:
-      SecureVector<byte> output;
-      u32bit position;
-   };
-
-void do_pk_keygen_tests();
-extern void do_x509_tests();
-
-u32bit validate_dsa_sig(const std::string&, const std::vector<std::string>&);
-u32bit validate_dsa_ver(const std::string&, const std::vector<std::string>&);
-
-u32bit validate_rsa_enc(const std::string&, const std::vector<std::string>&);
-u32bit validate_rsa_enc_pkcs8(const std::string&,
-                              const std::vector<std::string>&);
-u32bit validate_rsa_sig(const std::string&, const std::vector<std::string>&);
-u32bit validate_rsa_ver(const std::string&, const std::vector<std::string>&);
-u32bit validate_rsa_ver_x509(const std::string&,
-                             const std::vector<std::string>&);
-u32bit validate_rw_ver(const std::string&, const std::vector<std::string>&);
-u32bit validate_rw_sig(const std::string&, const std::vector<std::string>&);
-u32bit validate_nr_sig(const std::string&, const std::vector<std::string>&);
-u32bit validate_elg_enc(const std::string&, const std::vector<std::string>&);
-u32bit validate_dh(const std::string&, const std::vector<std::string>&);
-u32bit validate_dlies(const std::string&, const std::vector<std::string>&);
-
-u32bit do_pk_validation_tests(const std::string& filename)
-   {
-   std::ifstream test_data(filename.c_str());
-
-   if(!test_data)
-      throw Botan::Stream_IO_Error("Couldn't open test file " + filename);
-
-   u32bit errors = 0, alg_count = 0;
-   std::string algorithm, print_algorithm;
-
-   while(!test_data.eof())
-      {
-      if(test_data.bad() || test_data.fail())
-         throw Botan::Stream_IO_Error("File I/O error reading from " +
-                                      filename);
-
-      std::string line;
-      std::getline(test_data, line);
-
-      strip_comments(line);
-      if(line.size() == 0) continue;
-
-      // Do line continuation
-      while(line[line.size()-1] == '\\' && !test_data.eof())
-         {
-         line.replace(line.size()-1, 1, "");
-         std::string nextline;
-         std::getline(test_data, nextline);
-         strip_comments(nextline);
-         if(nextline.size() == 0) continue;
-         line.push_back('\n');
-         line += nextline;
-         }
-
-      if(line[0] == '[' && line[line.size() - 1] == ']')
-         {
-         std::string old_algo = print_algorithm;
-         algorithm = line.substr(1, line.size() - 2);
-         print_algorithm = algorithm;
-         if(print_algorithm.find("_PKCS8") != std::string::npos)
-            print_algorithm.replace(print_algorithm.find("_PKCS8"), 6, "");
-         if(print_algorithm.find("_X509") != std::string::npos)
-            print_algorithm.replace(print_algorithm.find("_X509"), 5, "");
-         if(print_algorithm.find("_VA") != std::string::npos)
-            print_algorithm.replace(print_algorithm.find("_VA"), 3, "");
-
-         if(old_algo != print_algorithm && old_algo != "")
-            {
-            std::cout << std::endl;
-            alg_count = 0;
-            }
-
-         if(old_algo != print_algorithm)
-            std::cout << "Testing " << print_algorithm << ": ";
-         continue;
-         }
-
-      std::cout << '.';
-      std::cout.flush();
-
-      std::vector<std::string> substr = parse(line);
-
-#if DEBUG
-      std::cout << "Testing: " << print_algorithm << std::endl;
-#endif
-
-      u32bit new_errors = 0;
-
-      if(algorithm.find("DSA/") != std::string::npos)
-         new_errors = validate_dsa_sig(algorithm, substr);
-      else if(algorithm.find("DSA_VA/") != std::string::npos)
-         new_errors = validate_dsa_ver(algorithm, substr);
-
-      else if(algorithm.find("RSAES_PKCS8/") != std::string::npos)
-         new_errors = validate_rsa_enc_pkcs8(algorithm, substr);
-      else if(algorithm.find("RSAVA_X509/") != std::string::npos)
-         new_errors = validate_rsa_ver_x509(algorithm, substr);
-
-      else if(algorithm.find("RSAES/") != std::string::npos)
-         new_errors = validate_rsa_enc(algorithm, substr);
-      else if(algorithm.find("RSASSA/") != std::string::npos)
-         new_errors = validate_rsa_sig(algorithm, substr);
-      else if(algorithm.find("RSAVA/") != std::string::npos)
-         new_errors = validate_rsa_ver(algorithm, substr);
-      else if(algorithm.find("RWVA/") != std::string::npos)
-         new_errors = validate_rw_ver(algorithm, substr);
-      else if(algorithm.find("RW/") != std::string::npos)
-         new_errors = validate_rw_sig(algorithm, substr);
-      else if(algorithm.find("NR/") != std::string::npos)
-         new_errors = validate_nr_sig(algorithm, substr);
-      else if(algorithm.find("ElGamal/") != std::string::npos)
-         new_errors = validate_elg_enc(algorithm, substr);
-      else if(algorithm.find("DH/") != std::string::npos)
-         new_errors = validate_dh(algorithm, substr);
-      else if(algorithm.find("DLIES/") != std::string::npos)
-         new_errors = validate_dlies(algorithm, substr);
-      else
-         std::cout << "WARNING: Unknown PK algorithm "
-                   << algorithm << std::endl;
-
-      alg_count++;
-      errors += new_errors;
-
-      if(new_errors)
-         std::cout << "ERROR: \"" << algorithm << "\" failed test #"
-                   << std::dec << alg_count << std::endl;
-      }
-
-   std::cout << std::endl;
-
-   global_state().set_prng(new ANSI_X931_RNG);
-   for(u32bit j = 0; j != 2; j++)
-      global_state().seed_prng(true, 384);
-
-   do_pk_keygen_tests();
-   do_x509_tests();
-
-   return errors;
-   }
+namespace {
 
 void dump_data(const SecureVector<byte>& out,
                const SecureVector<byte>& expected)
@@ -236,12 +65,10 @@ void validate_encryption(PK_Encryptor* e, PK_Decryptor* d,
                          bool& failure)
    {
    SecureVector<byte> message = decode_hex(input);
-
-   global_state().set_prng(new Fixed_Output_RNG(decode_hex(random)));
-
    SecureVector<byte> expected = decode_hex(exp);
+   Fixed_Output_RNG rng(decode_hex(random));
 
-   SecureVector<byte> out = e->encrypt(message);
+   SecureVector<byte> out = e->encrypt(message, rng);
    if(out != expected)
       {
       std::cout << "FAILED (encrypt): " << algo << std::endl;
@@ -249,10 +76,6 @@ void validate_encryption(PK_Encryptor* e, PK_Decryptor* d,
       failure = true;
       }
 
-   global_state().set_prng(new ANSI_X931_RNG);
-   for(u32bit j = 0; j != 2; j++)
-      global_state().seed_prng(true, 384);
-
    validate_decryption(d, algo, out, message, failure);
    delete e;
    }
@@ -262,11 +85,11 @@ void validate_signature(PK_Verifier* v, PK_Signer* s, const std::string& algo,
                         const std::string& exp, bool& failure)
    {
    SecureVector<byte> message = decode_hex(input);
-   global_state().set_prng(new Fixed_Output_RNG(decode_hex(random)));
 
    SecureVector<byte> expected = decode_hex(exp);
 
-   SecureVector<byte> sig = s->sign_message(message, message.size());
+   Fixed_Output_RNG rng(decode_hex(random));
+   SecureVector<byte> sig = s->sign_message(message, message.size(), rng);
 
    if(sig != expected)
       {
@@ -290,10 +113,6 @@ void validate_signature(PK_Verifier* v, PK_Signer* s, const std::string& algo,
       failure = true;
       }
 
-   global_state().set_prng(new ANSI_X931_RNG);
-   for(u32bit j = 0; j != 2; j++)
-      global_state().seed_prng(true, 384);
-
    delete v;
    delete s;
    }
@@ -318,7 +137,8 @@ void validate_kas(PK_Key_Agreement* kas, const std::string& algo,
    }
 
 u32bit validate_rsa_enc_pkcs8(const std::string& algo,
-                              const std::vector<std::string>& str)
+                              const std::vector<std::string>& str,
+                              RandomNumberGenerator& rng)
    {
    if(str.size() != 4 && str.size() != 5)
       throw Exception("Invalid input from pk_valid.dat");
@@ -331,7 +151,7 @@ u32bit validate_rsa_enc_pkcs8(const std::string& algo,
    DataSource_Memory keysource(reinterpret_cast<const byte*>(str[0].c_str()),
                                str[0].length());
 
-   Private_Key* privkey = PKCS8::load_key(keysource, pass);
+   Private_Key* privkey = PKCS8::load_key(keysource, rng, pass);
 
    RSA_PrivateKey* rsapriv = dynamic_cast<RSA_PrivateKey*>(privkey);
    if(!rsapriv)
@@ -351,13 +171,16 @@ u32bit validate_rsa_enc_pkcs8(const std::string& algo,
    }
 
 u32bit validate_rsa_enc(const std::string& algo,
-                        const std::vector<std::string>& str)
+                        const std::vector<std::string>& str,
+                        RandomNumberGenerator& rng)
    {
    if(str.size() != 6)
       throw Exception("Invalid input from pk_valid.dat");
 
-   RSA_PrivateKey privkey(to_bigint(str[1]), to_bigint(str[2]),
+   RSA_PrivateKey privkey(rng,
+                          to_bigint(str[1]), to_bigint(str[2]),
                           to_bigint(str[0]));
+
    RSA_PublicKey pubkey = privkey;
 
    std::string eme = algo.substr(6, std::string::npos);
@@ -371,13 +194,14 @@ u32bit validate_rsa_enc(const std::string& algo,
    }
 
 u32bit validate_elg_enc(const std::string& algo,
-                        const std::vector<std::string>& str)
+                        const std::vector<std::string>& str,
+                        RandomNumberGenerator& rng)
    {
    if(str.size() != 6 && str.size() != 7)
       throw Exception("Invalid input from pk_valid.dat");
 
    DL_Group domain(to_bigint(str[0]), to_bigint(str[1]));
-   ElGamal_PrivateKey privkey(domain, to_bigint(str[2]), to_bigint(str[3]));
+   ElGamal_PrivateKey privkey(rng, domain, to_bigint(str[2]));
    ElGamal_PublicKey pubkey = privkey;
 
    std::string eme = algo.substr(8, std::string::npos);
@@ -398,13 +222,16 @@ u32bit validate_elg_enc(const std::string& algo,
    }
 
 u32bit validate_rsa_sig(const std::string& algo,
-                        const std::vector<std::string>& str)
+                        const std::vector<std::string>& str,
+                        RandomNumberGenerator& rng)
    {
    if(str.size() != 6)
       throw Exception("Invalid input from pk_valid.dat");
 
-   RSA_PrivateKey privkey(to_bigint(str[1]), to_bigint(str[2]),
+   RSA_PrivateKey privkey(rng,
+                          to_bigint(str[1]), to_bigint(str[2]),
                           to_bigint(str[0]));
+
    RSA_PublicKey pubkey = privkey;
 
    std::string emsa = algo.substr(7, std::string::npos);
@@ -493,12 +320,13 @@ u32bit validate_rw_ver(const std::string& algo,
    }
 
 u32bit validate_rw_sig(const std::string& algo,
-                       const std::vector<std::string>& str)
+                       const std::vector<std::string>& str,
+                       RandomNumberGenerator& rng)
    {
    if(str.size() != 6)
       throw Exception("Invalid input from pk_valid.dat");
 
-   RW_PrivateKey privkey(to_bigint(str[1]), to_bigint(str[2]),
+   RW_PrivateKey privkey(rng, to_bigint(str[1]), to_bigint(str[2]),
                          to_bigint(str[0]));
    RW_PublicKey pubkey = privkey;
 
@@ -513,7 +341,8 @@ u32bit validate_rw_sig(const std::string& algo,
    }
 
 u32bit validate_dsa_sig(const std::string& algo,
-                        const std::vector<std::string>& str)
+                        const std::vector<std::string>& str,
+                        RandomNumberGenerator& rng)
    {
    if(str.size() != 4 && str.size() != 5)
       throw Exception("Invalid input from pk_valid.dat");
@@ -526,7 +355,7 @@ u32bit validate_dsa_sig(const std::string& algo,
    DataSource_Memory keysource(reinterpret_cast<const byte*>(str[0].c_str()),
                                str[0].length());
 
-   Private_Key* privkey = PKCS8::load_key(keysource, pass);
+   Private_Key* privkey = PKCS8::load_key(keysource, rng, pass);
 
    DSA_PrivateKey* dsapriv = dynamic_cast<DSA_PrivateKey*>(privkey);
    if(!dsapriv)
@@ -578,13 +407,14 @@ u32bit validate_dsa_ver(const std::string& algo,
    }
 
 u32bit validate_nr_sig(const std::string& algo,
-                       const std::vector<std::string>& str)
+                       const std::vector<std::string>& str,
+                       RandomNumberGenerator& rng)
    {
    if(str.size() != 8)
       throw Exception("Invalid input from pk_valid.dat");
 
    DL_Group domain(to_bigint(str[0]), to_bigint(str[1]), to_bigint(str[2]));
-   NR_PrivateKey privkey(domain, to_bigint(str[4]), to_bigint(str[3]));
+   NR_PrivateKey privkey(rng, domain, to_bigint(str[4]));
    NR_PublicKey pubkey = privkey;
 
    std::string emsa = algo.substr(3, std::string::npos);
@@ -598,14 +428,15 @@ u32bit validate_nr_sig(const std::string& algo,
    }
 
 u32bit validate_dh(const std::string& algo,
-                   const std::vector<std::string>& str)
+                   const std::vector<std::string>& str,
+                   RandomNumberGenerator& rng)
    {
    if(str.size() != 5 && str.size() != 6)
       throw Exception("Invalid input from pk_valid.dat");
 
    DL_Group domain(to_bigint(str[0]), to_bigint(str[1]));
 
-   DH_PrivateKey mykey(domain, to_bigint(str[2]), 0);
+   DH_PrivateKey mykey(rng, domain, to_bigint(str[2]));
    DH_PublicKey otherkey(domain, to_bigint(str[3]));
 
    std::string kdf = algo.substr(3, std::string::npos);
@@ -623,15 +454,16 @@ u32bit validate_dh(const std::string& algo,
    }
 
 u32bit validate_dlies(const std::string& algo,
-                      const std::vector<std::string>& str)
+                      const std::vector<std::string>& str,
+                      RandomNumberGenerator& rng)
    {
    if(str.size() != 6)
       throw Exception("Invalid input from pk_valid.dat");
 
    DL_Group domain(to_bigint(str[0]), to_bigint(str[1]));
 
-   DH_PrivateKey from(domain, to_bigint(str[2]), 0);
-   DH_PrivateKey to(domain, to_bigint(str[3]), 0);
+   DH_PrivateKey from(rng, domain, to_bigint(str[2]));
+   DH_PrivateKey to(rng, domain, to_bigint(str[3]));
 
    const std::string opt_str = algo.substr(6, std::string::npos);
 
@@ -654,41 +486,41 @@ u32bit validate_dlies(const std::string& algo,
    return (failure ? 1 : 0);
    }
 
-void do_pk_keygen_tests()
+void do_pk_keygen_tests(RandomNumberGenerator& rng)
    {
    std::cout << "Testing PK key generation: " << std::flush;
 
    /* Putting each key in a block reduces memory pressure, speeds it up */
-#define IF_SIG_KEY(TYPE, BITS)     \
-   {                               \
-   TYPE key(BITS);                 \
-   key.check_key(true);            \
-   std::cout << '.' << std::flush; \
+#define IF_SIG_KEY(TYPE, BITS)              \
+   {                                        \
+   TYPE key(rng, BITS);                     \
+   key.check_key(rng, true);                \
+   std::cout << '.' << std::flush;          \
    }
 
-#define DL_SIG_KEY(TYPE, GROUP)    \
-   {                               \
-   TYPE key(DL_Group(GROUP));  \
-   key.check_key(true);            \
-   std::cout << '.' << std::flush; \
+#define DL_SIG_KEY(TYPE, GROUP)             \
+   {                                        \
+   TYPE key(rng, DL_Group(GROUP));          \
+   key.check_key(rng, true);                \
+   std::cout << '.' << std::flush;          \
    }
 
-#define DL_ENC_KEY(TYPE, GROUP)    \
-   {                               \
-   TYPE key(DL_Group(GROUP));  \
-   key.check_key(true);            \
-   std::cout << '.' << std::flush; \
+#define DL_ENC_KEY(TYPE, GROUP)             \
+   {                                        \
+   TYPE key(rng, DL_Group(GROUP));          \
+   key.check_key(rng, true);                \
+   std::cout << '.' << std::flush;          \
    }
 
-#define DL_KEY(TYPE, GROUP)        \
-   {                               \
-   TYPE key(DL_Group(GROUP));  \
-   key.check_key(true);            \
-   std::cout << '.' << std::flush; \
+#define DL_KEY(TYPE, GROUP)                 \
+   {                                        \
+   TYPE key(rng, DL_Group(GROUP));          \
+   key.check_key(rng, true);                \
+   std::cout << '.' << std::flush;          \
    }
 
-   IF_SIG_KEY(RSA_PrivateKey, 512);
-   IF_SIG_KEY(RW_PrivateKey, 512);
+   IF_SIG_KEY(RSA_PrivateKey, 1024);
+   IF_SIG_KEY(RW_PrivateKey, 1024);
 
    DL_SIG_KEY(DSA_PrivateKey, "dsa/jce/512");
    DL_SIG_KEY(DSA_PrivateKey, "dsa/jce/768");
@@ -708,3 +540,123 @@ void do_pk_keygen_tests()
 
    std::cout << std::endl;
    }
+
+}
+
+u32bit do_pk_validation_tests(const std::string& filename,
+                              RandomNumberGenerator& rng)
+   {
+   std::ifstream test_data(filename.c_str());
+
+   if(!test_data)
+      throw Botan::Stream_IO_Error("Couldn't open test file " + filename);
+
+   u32bit errors = 0, alg_count = 0;
+   std::string algorithm, print_algorithm;
+
+   while(!test_data.eof())
+      {
+      if(test_data.bad() || test_data.fail())
+         throw Botan::Stream_IO_Error("File I/O error reading from " +
+                                      filename);
+
+      std::string line;
+      std::getline(test_data, line);
+
+      strip_comments(line);
+      if(line.size() == 0) continue;
+
+      // Do line continuation
+      while(line[line.size()-1] == '\\' && !test_data.eof())
+         {
+         line.replace(line.size()-1, 1, "");
+         std::string nextline;
+         std::getline(test_data, nextline);
+         strip_comments(nextline);
+         if(nextline.size() == 0) continue;
+         line.push_back('\n');
+         line += nextline;
+         }
+
+      if(line[0] == '[' && line[line.size() - 1] == ']')
+         {
+         std::string old_algo = print_algorithm;
+         algorithm = line.substr(1, line.size() - 2);
+         print_algorithm = algorithm;
+         if(print_algorithm.find("_PKCS8") != std::string::npos)
+            print_algorithm.replace(print_algorithm.find("_PKCS8"), 6, "");
+         if(print_algorithm.find("_X509") != std::string::npos)
+            print_algorithm.replace(print_algorithm.find("_X509"), 5, "");
+         if(print_algorithm.find("_VA") != std::string::npos)
+            print_algorithm.replace(print_algorithm.find("_VA"), 3, "");
+
+         if(old_algo != print_algorithm && old_algo != "")
+            {
+            std::cout << std::endl;
+            alg_count = 0;
+            }
+
+         if(old_algo != print_algorithm)
+            std::cout << "Testing " << print_algorithm << ": ";
+         continue;
+         }
+
+      std::cout << '.';
+      std::cout.flush();
+
+      std::vector<std::string> substr = parse(line);
+
+#if DEBUG
+      std::cout << "Testing: " << print_algorithm << std::endl;
+#endif
+
+      u32bit new_errors = 0;
+
+      if(algorithm.find("DSA/") != std::string::npos)
+         new_errors = validate_dsa_sig(algorithm, substr, rng);
+      else if(algorithm.find("DSA_VA/") != std::string::npos)
+         new_errors = validate_dsa_ver(algorithm, substr);
+
+      else if(algorithm.find("RSAES_PKCS8/") != std::string::npos)
+         new_errors = validate_rsa_enc_pkcs8(algorithm, substr, rng);
+      else if(algorithm.find("RSAVA_X509/") != std::string::npos)
+         new_errors = validate_rsa_ver_x509(algorithm, substr);
+
+      else if(algorithm.find("RSAES/") != std::string::npos)
+         new_errors = validate_rsa_enc(algorithm, substr, rng);
+      else if(algorithm.find("RSASSA/") != std::string::npos)
+         new_errors = validate_rsa_sig(algorithm, substr, rng);
+      else if(algorithm.find("RSAVA/") != std::string::npos)
+         new_errors = validate_rsa_ver(algorithm, substr);
+      else if(algorithm.find("RWVA/") != std::string::npos)
+         new_errors = validate_rw_ver(algorithm, substr);
+      else if(algorithm.find("RW/") != std::string::npos)
+         new_errors = validate_rw_sig(algorithm, substr, rng);
+      else if(algorithm.find("NR/") != std::string::npos)
+         new_errors = validate_nr_sig(algorithm, substr, rng);
+      else if(algorithm.find("ElGamal/") != std::string::npos)
+         new_errors = validate_elg_enc(algorithm, substr, rng);
+      else if(algorithm.find("DH/") != std::string::npos)
+         new_errors = validate_dh(algorithm, substr, rng);
+      else if(algorithm.find("DLIES/") != std::string::npos)
+         new_errors = validate_dlies(algorithm, substr, rng);
+      else
+         std::cout << "WARNING: Unknown PK algorithm "
+                   << algorithm << std::endl;
+
+      alg_count++;
+      errors += new_errors;
+
+      if(new_errors)
+         std::cout << "ERROR: \"" << algorithm << "\" failed test #"
+                   << std::dec << alg_count << std::endl;
+      }
+
+   std::cout << std::endl;
+
+   do_pk_keygen_tests(rng);
+   do_x509_tests(rng);
+
+   return errors;
+   }
+
