@@ -9,7 +9,7 @@ use File::Copy;
 
 my $MAJOR_VERSION = 1;
 my $MINOR_VERSION = 7;
-my $PATCH_VERSION = 6;
+my $PATCH_VERSION = 8;
 
 my $VERSION_STRING = "$MAJOR_VERSION.$MINOR_VERSION.$PATCH_VERSION";
 
@@ -823,7 +823,8 @@ sub dir_list {
     my ($dir) = @_;
     opendir(DIR, $dir) or croak("Couldn't read directory '$dir' ($!)");
 
-    my @listing = grep { $_ ne File::Spec->curdir() and
+    my @listing = grep { !/#/ and
+                         $_ ne File::Spec->curdir() and
                          $_ ne File::Spec->updir() } readdir DIR;
 
     closedir DIR;
@@ -903,6 +904,8 @@ sub find_mp_bits {
     my $seen_mp_module = undef;
 
     foreach my $modname (@modules_list) {
+        croak("Unknown module $modname") unless defined $MODULES{$modname};
+
         my %modinfo = %{ $MODULES{$modname} };
         if($modinfo{'mp_bits'}) {
             if(defined($seen_mp_module) and $modinfo{'mp_bits'} != $mp_bits) {
@@ -943,6 +946,16 @@ sub load_modules {
 
     foreach my $mod (sort keys %{$$config{'modules'}}) {
         load_module($config, $mod);
+
+        foreach my $req_mod (@{$MODULES{$mod}{'requires'}}) {
+            unless(defined($$config{'modules'}{$req_mod})) {
+                autoconfig("Module $req_mod - required by $mod");
+                $$config{'modules'}{$req_mod} = 1;
+                load_module($config, $req_mod);
+            }
+        }
+
+
     }
 
     my $gen_defines = sub {
@@ -1317,6 +1330,7 @@ sub get_module_info {
        read_list($_, $reader, 'add', list_push(\@{$info{'add'}}));
        read_list($_, $reader, 'replace', list_push(\@{$info{'replace'}}));
        read_list($_, $reader, 'ignore', list_push(\@{$info{'ignore'}}));
+       read_list($_, $reader, 'requires', list_push(\@{$info{'requires'}}));
 
        read_list($_, $reader, 'libs',
                  sub {
