@@ -12,6 +12,9 @@ This file is in the public domain
 #include <iostream>
 #include <fstream>
 #include <string>
+#include <cstdlib>
+#include <memory>
+
 #include <botan/botan.h>
 #include <botan/rsa.h>
 using namespace Botan;
@@ -26,7 +29,7 @@ int main(int argc, char* argv[])
       }
 
    u32bit bits = std::atoi(argv[1]);
-   if(bits < 512 || bits > 4096)
+   if(bits < 1024 || bits > 4096)
       {
       std::cout << "Invalid argument for bitsize" << std::endl;
       return 1;
@@ -42,13 +45,16 @@ int main(int argc, char* argv[])
 
    try
       {
-      RSA_PrivateKey key(bits);
+      std::auto_ptr<RandomNumberGenerator> rng(
+         RandomNumberGenerator::make_rng());
+
+      RSA_PrivateKey key(*rng, bits);
       pub << X509::PEM_encode(key);
 
       if(argc == 2)
          priv << PKCS8::PEM_encode(key);
       else
-         priv << PKCS8::PEM_encode(key, argv[2]);
+         priv << PKCS8::PEM_encode(key, *rng, argv[2]);
       }
    catch(std::exception& e)
       {
