@@ -21,8 +21,10 @@ class BOTAN_DLL EME1 : public EME
       EME1(const std::string&, const std::string&, const std::string& = "");
       ~EME1() { delete mgf; }
    private:
-      SecureVector<byte> pad(const byte[], u32bit, u32bit) const;
+      SecureVector<byte> pad(const byte[], u32bit, u32bit,
+                             RandomNumberGenerator&) const;
       SecureVector<byte> unpad(const byte[], u32bit, u32bit) const;
+
       const u32bit HASH_LENGTH;
       SecureVector<byte> Phash;
       MGF* mgf;
@@ -36,7 +38,8 @@ class BOTAN_DLL EME_PKCS1v15 : public EME
    public:
       u32bit maximum_input_size(u32bit) const;
    private:
-      SecureVector<byte> pad(const byte[], u32bit, u32bit) const;
+      SecureVector<byte> pad(const byte[], u32bit, u32bit,
+                             RandomNumberGenerator&) const;
       SecureVector<byte> unpad(const byte[], u32bit, u32bit) const;
    };
 
