@@ -14,7 +14,7 @@ namespace Botan {
 * Rabin-Williams Public Key                      *
 *************************************************/
 class BOTAN_DLL RW_PublicKey : public PK_Verifying_with_MR_Key,
-                     public virtual IF_Scheme_PublicKey
+                               public virtual IF_Scheme_PublicKey
    {
    public:
       std::string algo_name() const { return "RW"; }
@@ -31,18 +31,22 @@ class BOTAN_DLL RW_PublicKey : public PK_Verifying_with_MR_Key,
 * Rabin-Williams Private Key                     *
 *************************************************/
 class BOTAN_DLL RW_PrivateKey : public RW_PublicKey,
-                      public PK_Signing_Key,
-                      public IF_Scheme_PrivateKey
+                                public PK_Signing_Key,
+                                public IF_Scheme_PrivateKey
    {
    public:
-      SecureVector<byte> sign(const byte[], u32bit) const;
+      SecureVector<byte> sign(const byte[], u32bit,
+                              RandomNumberGenerator& rng) const;
 
-      bool check_key(bool) const;
+      bool check_key(RandomNumberGenerator& rng, bool) const;
 
       RW_PrivateKey() {}
-      RW_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
+
+      RW_PrivateKey(RandomNumberGenerator&,
+                    const BigInt&, const BigInt&, const BigInt&,
                     const BigInt& = 0, const BigInt& = 0);
-      RW_PrivateKey(u32bit, u32bit = 2);
+
+      RW_PrivateKey(RandomNumberGenerator& rng, u32bit bits, u32bit = 2);
    };
 
 }
