@@ -1,6 +1,6 @@
 /*************************************************
 * File Tree Walking EntropySource Header File    *
-* (C) 1999-2007 Jack Lloyd                       *
+* (C) 1999-2008 Jack Lloyd                       *
 *************************************************/
 
 #ifndef BOTAN_EXT_ENTROPY_SRC_FTW_H__
@@ -16,14 +16,14 @@ namespace Botan {
 class FTW_EntropySource : public Buffered_EntropySource
    {
    public:
-      FTW_EntropySource(const std::string& = "/proc");
+      FTW_EntropySource(const std::string& root_dir);
    private:
       void do_fast_poll();
       void do_slow_poll();
-      void gather_from_dir(const std::string&);
-      void gather_from_file(const std::string&);
+
+      void poll(u32bit max_read);
+
       const std::string path;
-      u32bit files_read, max_read;
    };
 
 }
